summaryrefslogtreecommitdiff
path: root/src/lib/config.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2017-04-27 11:57:15 +0100
committerCarl Hetherington <cth@carlh.net>2017-04-27 11:57:15 +0100
commit1f7f758273eb3c98356438da897b7709f8cb87f0 (patch)
tree06fb17aa8ee01c91779402f1abb3c5d2a389ed7a /src/lib/config.h
parent350c6ca06fd782917586d039850c93f8f9613707 (diff)
Distinguish master DoM encode threads count from the server count.
Diffstat (limited to 'src/lib/config.h')
-rw-r--r--src/lib/config.h26
1 files changed, 18 insertions, 8 deletions
diff --git a/src/lib/config.h b/src/lib/config.h
index a574cc261..40380f825 100644
--- a/src/lib/config.h
+++ b/src/lib/config.h
@@ -47,9 +47,14 @@ class Film;
class Config : public boost::noncopyable
{
public:
- /** @return number of threads to use for J2K encoding on the local machine */
- int num_local_encoding_threads () const {
- return _num_local_encoding_threads;
+ /** @return number of threads which a master DoM should use for J2K encoding on the local machine */
+ int master_encoding_threads () const {
+ return _master_encoding_threads;
+ }
+
+ /** @return number of threads which a server should use for J2K encoding on the local machine */
+ int server_encoding_threads () const {
+ return _server_encoding_threads;
}
boost::optional<boost::filesystem::path> default_directory () const {
@@ -316,9 +321,12 @@ public:
return _preview_sound_output;
}
- /** @param n New number of local encoding threads */
- void set_num_local_encoding_threads (int n) {
- maybe_set (_num_local_encoding_threads, n);
+ void set_master_encoding_threads (int n) {
+ maybe_set (_master_encoding_threads, n);
+ }
+
+ void set_server_encoding_threads (int n) {
+ maybe_set (_server_encoding_threads, n);
}
void set_default_directory (boost::filesystem::path d) {
@@ -628,8 +636,10 @@ private:
changed (prop);
}
- /** number of threads to use for J2K encoding on the local machine */
- int _num_local_encoding_threads;
+ /** number of threads which a master DoM should use for J2K encoding on the local machine */
+ int _master_encoding_threads;
+ /** number of threads which a server should use for J2K encoding on the local machine */
+ int _server_encoding_threads;
/** default directory to put new films in */
boost::optional<boost::filesystem::path> _default_directory;
/** base port number to use for J2K encoding servers;